@@ -30,10 +30,20 @@
     'horizon.framework.util.i18n.gettext',
     'horizon.app.core.openstack-service-api.magnum',
     'horizon.app.core.openstack-service-api.nova',
-    'horizon.app.core.openstack-service-api.glance'
+    'horizon.app.core.openstack-service-api.glance',
+    'horizon.dashboard.container-infra.cluster-templates.distros'
   ];
 
-  function ClusterTemplateWorkflow($q, basePath, workflowService, gettext, magnum, nova, glance) {
+  function ClusterTemplateWorkflow(
+    $q,
+    basePath,
+    workflowService,
+    gettext,
+    magnum,
+    nova,
+    glance,
+    distros
+  ) {
     var workflow = {
       init: init,
       update: update
@@ -55,8 +65,10 @@
       var supportedNetworkDrivers = {
         initial: [{value:"", name: gettext("Choose a Network Driver")},
                   {value: "docker", name: gettext("Docker")},
-                  {value: "flannel", name: gettext("Flannel")}],
-        kubernetes: [{value:"flannel", name: gettext("Flannel")}],
+                  {value: "flannel", name: gettext("Flannel")},
+                  {value: "calico", name: gettext("Calico")}],
+        kubernetes: [{value:"flannel", name: gettext("Flannel")},
+                     {value: "calico", name: gettext("Calico")}],
         swarm: [{value:"docker", name: gettext("Docker")},
                 {value:"flannel", name: gettext("Flannel")}],
         "swarm-mode": [{value:"docker", name: gettext("Docker")},
@@ -319,11 +331,7 @@
                         {
                           key: 'volume_driver',
                           type: 'select',
-                          titleMap: [
-                            {value: '', name: gettext('Choose a Volume Driver')},
-                            {value: 'cinder', name: gettext('Cinder')},
-                            {value: 'rexray', name: gettext('Rexray')}
-                          ]
+                          titleMap: supportedVolumeDrivers.initial
                         }
                       ]
                     },
@@ -381,11 +389,7 @@
                         {
                           key: 'network_driver',
                           type: 'select',
-                          titleMap: [
-                            {value: "", name: gettext("Choose a Network Driver")},
-                            {value: "docker", name: gettext("Docker")},
-                            {value: "flannel", name: gettext("Flannel")}
-                          ]
+                          titleMap: supportedNetworkDrivers.initial
                         },
                         {
                           key: 'http_proxy'
@@ -512,7 +516,10 @@
     function onGetImages(response) {
       images = [{value:"", name: gettext("Choose an Image")}];
       angular.forEach(response.data.items, function(item) {
-        images.push({value: item.name, name: item.name});
+        if (!angular.isUndefined(item.properties) &&
+          distros.indexOf(item.properties.os_distro) >= 0) {
+          images.push({value: item.name, name: item.name});
+        }
       });
       form[0].tabs[1].items[0].items[0].items[0].titleMap = images;
       var deferred = $q.defer();
